{ pkgs, ... }:

{
  imports = [
    ./accounts.secret.nix
    ./git

    ../../modules/window_manager
    ../../modules/terminal/wezterm.nix
    ../../modules/terminal/alacritty.nix
    ../../modules/shell.nix

    ../../modules/notifications
    ../../modules/file_manager
    ../../modules/mail
    ../../modules/pass.nix

    ../../modules/dev_tools.nix
    ../../modules/editor.nix

    ../../modules/work_tools.nix

    ../../modules/themes
    ../../modules/themes/catppuccin/frappe.nix
  ];

  xdg.enable = true;

  home.keyboard = {
    model = "pc105";
    layout = "us,ru";
    variant = "dvorak,";
    options = [ "grp:win_space_toggle" ];
  };

  # a fork of firefox, focused on privacy, security and freedom
  programs.librewolf = {
    enable = true;
    package = with pkgs.unstable; librewolf.override {
      nativeMessagingHosts = [ passff-host ];
    };
    # See: https://librewolf.net/docs/settings/
    settings = {
      "webgl.disabled" = false;
    };
  };

  home.packages = with pkgs.unstable; [
    tdesktop # telegram client
    nheko # matrix client
    image-roll
    vlc
    gimp
    libresprite
    # playerctl

    # office
    libreoffice
    hunspell
    hunspellDicts.ru_RU
    hunspellDicts.en_US

    # tools
    procs
    bottom
    asciinema # record the terminal
    neofetch # command-line system information
    bind.dnsutils
    kubo # ipfs

    # browsers
    # ungoogled-chromium
    tor-browser-bundle-bin

    woodpecker-cli

    # games
    mindustry
    simplex-chat-desktop
  ];

  home.file = {
    "pictures/wallpapers" = {
      source = ./wallpapers;
      recursive = true;
    };
  };

}
